@@ -3,7 +3,6 @@ package Perinci::Access::Schemeless;
 use 5.010001;
 use strict;
 use warnings;
-use experimental 'smartmatch';
 use Log::ger;
 
 use parent qw(Perinci::Access::Base);
@@ -19,9 +18,9 @@ use Tie::Cache;
 use URI::Split qw(uri_split uri_join);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-08-25'; # DATE
+our $DATE = '2023-07-09'; # DATE
 our $DIST = 'Perinci-Access-Perl'; # DIST
-our $VERSION = '0.898'; # VERSION
+our $VERSION = '0.899'; # VERSION
 
 our $re_perl_package =
     qr/\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9][A-Za-z_0-9]*)*\z/;
@@ -156,11 +155,11 @@ sub _parse_uri {
     }
 
     my $sch = $req->{-uri_scheme} // "";
-    if (defined($self->{allow_schemes}) && !($sch ~~ $self->{allow_schemes})) {
+    if (defined($self->{allow_schemes}) && !(grep { $_ eq $sch } @{ $self->{allow_schemes} })) {
         return err(501,
                    "Unsupported uri scheme (does not match allow_schemes)");
     }
-    if (defined($self->{deny_schemes}) && ($sch ~~ $self->{deny_schemes})) {
+    if (defined($self->{deny_schemes}) && (grep { $_ eq $sch } @{ $self->{deny_schemes} })) {
         return err(501, "Unsupported uri scheme (matches deny_schemes)");
     }
 
@@ -492,7 +491,7 @@ sub request {
     return err(501, "Action '$action' not implemented for ".
                    "'$req->{-type}' entity")
         unless $am->{applies_to}[0] eq '*' ||
-            $req->{-type} ~~ @{ $am->{applies_to} };
+            (grep { $_ eq $req->{-type} } @{ $am->{applies_to} });
 
     my $meth = "action_$action";
     # check transaction
@@ -1049,7 +1048,7 @@ Perinci::Access::Schemeless - Base class for Perinci::Access::Perl
 
 =head1 VERSION
 
-This document describes version 0.898 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2022-08-25.
+This document describes version 0.899 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2023-07-09.
 
 =head1 DESCRIPTION
 
@@ -1307,7 +1306,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
